%define major		0.7
%define libname		%mklibname jxl %{major}
%define libnamethreads	%mklibname jxl_threads %{major}
%define develname	%mklibname jxl -d

%bcond_without gimp_plugin
%bcond_without tcmalloc

Name:		libjxl
Version:	0.7.2
Release:	%mkrel 1
Summary:	JPEG XL reference implementation
License:	BSD
Group:		System/Libraries
URL:		https://jpegxl.info/
#Git-Clone:     https://github.com/libjxl/libjxl
Source0:	https://github.com/libjxl/libjxl/archive/refs/tags/v%{version}/%{name}-%{version}.tar.gz
Patch0:		libjxl-0.7.0-JPEGXL_ENABLE_PLUGINS.patch

BuildRequires:	asciidoc
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	python3dist(sphinx)
BuildRequires:	giflib-devel
BuildRequires:	pkgconfig(gflags)
BuildRequires:	pkgconfig(gmock)
BuildRequires:	pkgconfig(lcms2)
BuildRequires:	pkgconfig(libavif)
BuildRequires:	pkgconfig(libbrotlicommon)
BuildRequires:	pkgconfig(libbrotlidec)
BuildRequires:	pkgconfig(libbrotlienc)
BuildRequires:	pkgconfig(libhwy) >= 1.0
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libwebp)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(zlib)
%if %{with tcmalloc}
BuildRequires:	pkgconfig(libtcmalloc)
%endif
%if %{with gimp_plugin}
BuildRequires:	pkgconfig(gimp-2.0)
%endif

%description
JPEG XL is a raster-graphics file format that supports both lossy and
lossless compression.

This is the reference implementation of JPEG XL, with encoder and decoder.

#------------------------------------------------

%package -n	%{libname}
Summary:	Library for encoding and decoding JPEG XL raster graphic images
Group:		System/Libraries

%description -n	%{libname}
JPEG XL is a raster-graphics file format that supports both lossy and
lossless compression.

#------------------------------------------------

%package -n	%{libnamethreads}
Summary:	Library for encoding and decoding JPEG XL raster graphic images
Group:		System/Libraries

%description -n	%{libnamethreads}
JPEG XL is a raster-graphics file format that supports both lossy and
lossless compression.

#------------------------------------------------

%package -n	%{develname}
Summary:	Development package for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libnamethreads} = %{version}-%{release}
Provides:	jxl-devel = %{version}-%{release}

%description -n	%{develname}
Header files for development with %{name}.

#------------------------------------------------

%package	tools
Summary:	Command-line utilities to convert from/to JPEG XL
Group:		Development/Tools

%description	tools
Command-line utilities to convert from/to JPEG XL.

#------------------------------------------------
%if %{with gimp_plugin}

%package -n	gimp-plugin-jxl
Summary:	A plugin for loading and saving JPEG-XL images
Group:		Graphics/Editors and Converters
Requires:	gimp

%description -n	gimp-plugin-jxl
This is a GIMP plugin for loading and saving JPEG-XL images.
%endif

#------------------------------------------------

%prep
%autosetup -p1

%build
%ifarch armv7hl
export CXXFLAGS="%optflags -DHWY_COMPILE_ONLY_EMU128"
%endif

%cmake  -DJPEGXL_FORCE_SYSTEM_HWY=ON \
%ifarch armv7hl
	-DHWY_CMAKE_ARM7=ON \
%endif
	-DJPEGXL_FORCE_SYSTEM_BROTLI=ON \
	-DJPEGXL_FORCE_SYSTEM_LCMS2=ON \
	-DJPEGXL_FORCE_SYSTEM_GTEST=ON \
	-DBUILD_TESTING=OFF \
%if %{with gimp_plugin}
	-DJPEGXL_ENABLE_PLUGINS=ON \
	-DJPEGXL_ENABLE_PLUGIN_GDKPIXBUF=OFF \
%else
	-DJPEGXL_ENABLE_PLUGINS=OFF \
%endif
	-DJPEGXL_ENABLE_SKCMS=OFF \
	-DJPEGXL_ENABLE_SJPEG=OFF \
	-DJPEGXL_STATIC=OFF \
	-DBUNDLE_LIBPNG_DEFAULT=OFF

%cmake_build -- all doc

%install
%cmake_install

# we don't want these
find %{buildroot} -name '*.a' -delete

%files -n %{libname}
%license LICENSE
%{_libdir}/libjxl.so.%{major}{,.*}

%files -n %{libnamethreads}
%license LICENSE
%{_libdir}/libjxl_threads.so.%{major}{,.*}

%files -n %{develname}
%doc CONTRIBUTING.md CONTRIBUTORS README.md
%{_includedir}/jxl/
%{_libdir}/libjxl.so
%{_libdir}/libjxl_threads.so
%{_libdir}/pkgconfig/*.pc

%files tools
%doc CONTRIBUTING.md CONTRIBUTORS README.md
%doc %{_vpath_builddir}/html
%{_bindir}/cjpeg_hdr
%{_bindir}/*xl*
%{_mandir}/man1/*xl*.1.*
%{_datadir}/mime/packages/image-jxl.xml

%if %{with gimp_plugin}
%files -n gimp-plugin-jxl
%license LICENSE
%{_libdir}/gimp/2.0/plug-ins/file-jxl/
%endif


%changelog
* Fri Jan 10 2025 ns80 <ns80> 0.7.2-1.mga9
+ Revision: 2136976
- new version 0.7.2 for CVE-2024-11403 and CVE-2024-11498 (mga#33818)

* Sun Feb 05 2023 daviddavid <daviddavid> 0.7.0-6.mga9
+ Revision: 1938613
- enable jpegxl gimp plugin
- enable html docs and manpages support
- enable tcmalloc support
- use system gtest/gmock

* Wed Nov 30 2022 pterjan <pterjan> 0.7.0-5.mga9
+ Revision: 1913529
- One more attempt at fixing armv7hl

* Mon Nov 28 2022 kekepower <kekepower> 0.7.0-4.mga9
+ Revision: 1912182
- Bump rel
- Another try at fixing the build on arm

* Mon Nov 28 2022 pterjan <pterjan> 0.7.0-3.mga9
+ Revision: 1912176
- Try to fix build on armv7hl

* Fri Nov 18 2022 daviddavid <daviddavid> 0.7.0-2.mga9
+ Revision: 1908617
- add some build requirements
- exclude armv7 arch for now

* Fri Nov 18 2022 daviddavid <daviddavid> 0.7.0-1.mga9
+ Revision: 1908611
- initial package libjxl

